(**********************************************************************

                              mus.inc

        - include file for Turbo 3.0. Interface to mouse driver for
          Tiki 100 Rev. C

        Author: Jarle Strand

 ************************************************************************)



CONST
  m_int = $AA;             (* mouse interrupt *)
  m_fts = 684;             (* mouse footstep *)

TYPE
  m_registers = RECORD
                  AX,BX,CX,DX,BP,SI,DI,DS,ES,Flags: Integer;
                END;

VAR
  m_x,m_y: Integer;        (* mouse position *)
  m_switch: Byte;          (* mouse switch *)



PROCEDURE M_init(mode: Integer);
VAR
  r: m_registers;
BEGIN

  (* Check footprint *)
  IF MemW[0:m_fts]<>1234 THEN BEGIN
    Writeln;
    Writeln('Dette programmet krever musedriver.');
    Writeln;
    HALT;
  END;

  (* Enable Mouse *)
  r.ax := 0;
  r.bx := 1;
  Intr(m_int,r);

  (* Set Mode *)
  r.ax := 4;
  r.bx := mode;
  Intr(m_int,r);  

  (* Update position and switch *)
  r.ax := 10;
  Intr(m_int,r);
  m_switch := r.ax AND $FF;
  m_x := r.bx;
  m_y := r.cx;
END;



PROCEDURE M_getpos(VAR x,y:Integer);
VAR
  r: m_registers;
BEGIN
  (* Update position and switch *)
  r.ax := 10;
  Intr(m_int,r);
  m_switch := r.ax AND $FF;
  m_x := r.bx;
  m_y := r.cx;

  x := m_x;
  y := m_y;
END;



PROCEDURE M_setpos(x,y:Integer);
VAR
  r: m_registers;
BEGIN
  (* Update position *)
  r.ax := 9;
  r.bx := x;
  r.cx := y;
  Intr(m_int,r);

  m_x := x;
  m_y := y;
END;



FUNCTION M_switch1: Boolean;
VAR
  r: m_registers;
BEGIN
  (* Return TRUE if switch1 is down, else FALSE *)
  M_switch1 := m_switch AND 4 = 0;
END;



FUNCTION M_switch2: Boolean;
VAR
  r: m_registers;
BEGIN
  (* Return TRUE if switch2 is down, else FALSE *)
  M_switch2 := m_switch AND 2 = 0;
END;



FUNCTION M_switch3: Boolean;
VAR
  r: m_registers;
BEGIN
  (* Return TRUE if switch3 is down, else FALSE *)
  M_switch3 := m_switch AND 1 = 0;
END;



FUNCTION M_event:Boolean;
VAR
  r: m_registers;
  event: Boolean;
BEGIN
  event := FALSE;

  r.ax := 10;
  Intr(m_int,r);

  IF m_switch <> r.ax AND $FF THEN event := TRUE;
  m_switch := r.ax AND $FF;
  IF m_x <> r.bx THEN event := TRUE;
  m_x := r.bx;
  IF m_y <> r.cx THEN event := TRUE;
  m_y := r.cx;

  M_event := event;
END;



PROCEDURE M_setarea( x1,y1,x2,y2: Integer);
VAR
  r: m_registers;
BEGIN
  (* Set Upper Left *)
  r.ax := 5;
  r.bx := x1;
  r.cx := y1;
  Intr(m_int,r);

  (* Set Lower Right *)
  r.ax := 6;
  r.bx := x2;
  r.cx := y2;
  Intr(m_int,r);
END;
